@@ -36,8 +36,8 @@
 
 /* Include the marshallers */
 #include <glib-object.h>
+#include <gio/gio.h>
 #include "gdk-pixbuf-marshal.c"
-#include "gdk-pixbuf-alias.h"
 
 static void gdk_pixbuf_finalize     (GObject        *object);
 static void gdk_pixbuf_set_property (GObject        *object,
@@ -63,7 +63,11 @@ enum
   PROP_PIXELS
 };
 
-G_DEFINE_TYPE (GdkPixbuf, gdk_pixbuf, G_TYPE_OBJECT)
+static void gdk_pixbuf_icon_iface_init (GIconIface *iface);
+
+G_DEFINE_TYPE_WITH_CODE (GdkPixbuf, gdk_pixbuf, G_TYPE_OBJECT,
+                         G_IMPLEMENT_INTERFACE (G_TYPE_ICON,
+                                                gdk_pixbuf_icon_iface_init))
 
 static void 
 gdk_pixbuf_init (GdkPixbuf *pixbuf)
@@ -188,7 +192,7 @@ gdk_pixbuf_finalize (GObject *object)
 
 
 /**
- * gdk_pixbuf_ref:
+ * gdk_pixbuf_ref: (skip)
  * @pixbuf: A pixbuf.
  *
  * Adds a reference to a pixbuf.
@@ -204,7 +208,7 @@ gdk_pixbuf_ref (GdkPixbuf *pixbuf)
 }
 
 /**
- * gdk_pixbuf_unref:
+ * gdk_pixbuf_unref: (skip)
  * @pixbuf: A pixbuf.
  *
  * Removes a reference from a pixbuf.
@@ -217,7 +221,12 @@ gdk_pixbuf_unref (GdkPixbuf *pixbuf)
         g_object_unref (pixbuf);
 }
 
-
+static void
+gdk_pixbuf_icon_iface_init (GIconIface *iface)
+{
+        iface->hash = g_direct_hash;
+        iface->equal = g_direct_equal;
+}
 
 /* Used as the destroy notification function for gdk_pixbuf_new() */
 static void
@@ -286,7 +295,7 @@ gdk_pixbuf_new (GdkColorspace colorspace,
  * Creates a new #GdkPixbuf with a copy of the information in the specified
  * @pixbuf.
  * 
- * Return value: A newly-created pixbuf with a reference count of 1, or %NULL if
+ * Return value: (transfer full): A newly-created pixbuf with a reference count of 1, or %NULL if
  * not enough memory could be allocated.
  **/
 GdkPixbuf *
@@ -335,7 +344,7 @@ gdk_pixbuf_copy (const GdkPixbuf *pixbuf)
  * @src_pixbuf will not be finalized until the new pixbuf
  * is finalized.
  * 
- * Return value: a new pixbuf 
+ * Return value: (transfer full): a new pixbuf 
  **/
 GdkPixbuf*
 gdk_pixbuf_new_subpixbuf (GdkPixbuf *src_pixbuf,
@@ -764,6 +773,3 @@ gdk_pixbuf_get_property (GObject         *object,
                   break;
           }
 }
-
-#define __GDK_PIXBUF_C__
-#include "gdk-pixbuf-aliasdef.c"
